@@ -1,21 +1,8 @@
 /*
- *   Copyright 2013 Marco Martin <mart@kde.org>
- *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2013 Marco Martin <mart@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "qmlobject.h"
 #include "private/kdeclarative_p.h"
@@ -26,9 +13,8 @@
 #include <QQuickItem>
 #include <QQmlIncubator>
 #include <QTimer>
-#include <QPointer>
 
-#include <qdebug.h>
+#include <QDebug>
 #include <kdeclarative.h>
 #include <KPackage/PackageLoader>
 
@@ -42,7 +28,7 @@ class QmlObjectIncubator : public QQmlIncubator
 public:
     QVariantHash m_initialProperties;
 protected:
-    void setInitialState(QObject *object) Q_DECL_OVERRIDE
+    void setInitialState(QObject *object) override
     {
         QHashIterator<QString, QVariant> i(m_initialProperties);
         while (i.hasNext()) {
@@ -100,8 +86,8 @@ void QmlObjectPrivate::errorPrint(QQmlComponent *component)
 {
     QString errorStr = QStringLiteral("Error loading QML file.\n");
     if (component->isError()) {
-        QList<QQmlError> errors = component->errors();
-        foreach (const QQmlError &error, errors) {
+        const QList<QQmlError> errors = component->errors();
+        for (const QQmlError &error : errors) {
             errorStr += (error.line() > 0 ? QString(QString::number(error.line()) + QLatin1String(": ")) : QLatin1String(""))
                         + error.description() + QLatin1Char('\n');
         }
@@ -141,36 +127,35 @@ void QmlObjectPrivate::scheduleExecutionEnd()
 }
 
 QmlObject::QmlObject(QObject *parent)
-    : QObject(parent),
-      d(new QmlObjectPrivate(this))
+    // cannot do : QmlObject(new QQmlEngine(this), d->engine->rootContext(), parent)
+    : QObject(parent)
+    , d(new QmlObjectPrivate(this))
+
 {
     d->engine = new QQmlEngine(this);
     d->rootContext = d->engine->rootContext();
     d->kdeclarative.setDeclarativeEngine(d->engine);
     d->kdeclarative.d->qmlObj = this;
-    //binds things like kconfig and icons
-    d->kdeclarative.setupBindings();
+
+    d->kdeclarative.setupContext();
+    KDeclarative::setupEngine(d->engine);
 }
 
 QmlObject::QmlObject(QQmlEngine *engine, QObject *parent)
-    : QObject(parent),
-      d(new QmlObjectPrivate(this))
+    : QmlObject(engine, engine->rootContext(), parent)
 {
-    if (engine) {
-        d->engine = engine;
-    } else {
-        d->engine = new QQmlEngine(this);
-    }
-    d->rootContext = d->engine->rootContext();
-    d->kdeclarative.setDeclarativeEngine(d->engine);
-    d->kdeclarative.d->qmlObj = this;
-    //binds things like kconfig and icons
-    d->kdeclarative.setupBindings();
+
 }
 
 QmlObject::QmlObject(QQmlEngine *engine, QQmlContext *rootContext, QObject *parent)
-    : QObject(parent),
-      d(new QmlObjectPrivate(this))
+    : QmlObject(engine, rootContext, nullptr /*call setupEngine*/, parent)
+{
+
+}
+
+QmlObject::QmlObject(QQmlEngine *engine, QQmlContext *rootContext, QmlObject *obj, QObject *parent)
+    : QObject(parent)
+    , d(new QmlObjectPrivate(this))
 {
     if (engine) {
         d->engine = engine;
@@ -185,8 +170,12 @@ QmlObject::QmlObject(QQmlEngine *engine, QQmlContext *rootContext, QObject *pare
     }
     d->kdeclarative.setDeclarativeEngine(d->engine);
     d->kdeclarative.d->qmlObj = this;
-    //binds things like kconfig and icons
-    d->kdeclarative.setupBindings();
+
+    d->kdeclarative.setupContext();
+
+    if (!obj) {
+        KDeclarative::setupEngine(d->engine);
+    }
 }
 
 QmlObject::~QmlObject()
@@ -351,7 +340,7 @@ QObject *QmlObject::createObjectFromComponent(QQmlComponent *component, QQmlCont
         //memory management
         component->setParent(object);
         //reparent to root object if wasn't specified otherwise by initialProperties
-        if (!initialProperties.contains(QStringLiteral("parent"))) {
+        if (!initialProperties.contains(QLatin1String("parent"))) {
             if (qobject_cast<QQuickItem *>(rootObject())) {
                 object->setProperty("parent", QVariant::fromValue(rootObject()));
             } else {
