@@ -1,27 +1,13 @@
 /*
- * <one line to give the library's name and an idea of what it does.>
- * Copyright (C) 2014  David Edmundson <davidedmundson@kde.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
- *
- */
+    SPDX-FileCopyrightText: 2014 David Edmundson <davidedmundson@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.1-or-later
+*/
 
 #ifndef KEYSEQUENCEHELPER_H
 #define KEYSEQUENCEHELPER_H
 
-#include <QObject>
+#include <QQuickItem>
 #include <QKeySequence>
 
 /**
@@ -33,12 +19,10 @@
 
 class KeySequenceHelperPrivate;
 
-class KeySequenceHelper : public QObject
+class KeySequenceHelper : public QQuickItem
 {
     Q_OBJECT
 
-    Q_FLAGS(ShortcutTypes)
-
     Q_PROPERTY(
         QKeySequence keySequence
         READ keySequence
@@ -60,6 +44,13 @@ class KeySequenceHelper : public QObject
         READ isModifierlessAllowed
         WRITE setModifierlessAllowed)
 
+    Q_PROPERTY(
+        ShortcutTypes checkAgainstShortcutTypes
+        READ checkAgainstShortcutTypes
+        WRITE setCheckAgainstShortcutTypes
+        NOTIFY checkAgainstShortcutTypesChanged
+    )
+
 public:
 
     enum ShortcutType {
@@ -68,11 +59,12 @@ public:
         GlobalShortcuts = 0x02      //!< Check against global shortcuts. @see KGlobalAccel
     };
     Q_DECLARE_FLAGS(ShortcutTypes, ShortcutType)
+    Q_FLAG(ShortcutTypes)
 
     /**
     * Constructor.
     */
-    explicit KeySequenceHelper(QObject* parent = 0);
+    explicit KeySequenceHelper(QQuickItem* parent = nullptr);
 
     /**
     * Destructs the widget.
@@ -116,11 +108,14 @@ public:
 
     bool isKeySequenceAvailable(const QKeySequence &keySequence) const;
 
+    ShortcutTypes checkAgainstShortcutTypes();
+    void setCheckAgainstShortcutTypes(ShortcutTypes types);
 
 Q_SIGNALS:
     void keySequenceChanged(const QKeySequence &seq);
     void shortcutDisplayChanged(const QString &string);
     void captureFinished();
+    void checkAgainstShortcutTypesChanged();
 
 public Q_SLOTS:
     void captureKeySequence();
